@@ -46,6 +46,3 @@ pub const TURING_MASHINE_ACCOUNT_PREFIX:usize = 75;
 
 /// The size of splu secondary state of Turing account 
 pub const SPLU_SECONDARY_STRUCT_LEN:usize = 33;
-
-/// The size of splu tertiary state of Turing account 
-pub const SPLU_TERTAIRY_STRUCT_LEN:usize = 66;
\ No newline at end of file
